@@ -17,7 +17,7 @@ from .utils.decorators import super_user_active_only
 @method_decorator(super_user_active_only, name='dispatch')
 class DirectoryTreeView(TemplateView):
 
-    template_name = 'directory_tree/index.html'
+    template_name = 'directory_tree/directory_tree_index.html'
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
